<?php

namespace Drupal\ptools;

/**
 * Trait useful to wrap database query objects to provide type hinting.
 *
 * @see \db_query()
 * @see \db_select()
 */
trait DatabaseConnectionTrait {

  /**
   * The database connection.
   *
   * @var \DatabaseConnection
   */
  protected $database;

  /**
   * Instantiates a SELECT query object.
   *
   * @param $table
   *   The base table for this query.
   * @param $alias
   *   The alias of the base table of this query.
   * @param $options
   *   An array of options on the query.
   *
   * @return \SelectQuery
   *   An appropriate SelectQuery object for this database connection.
   */
  protected function getSelectQuery($table, $alias = NULL, array $options = array()) {
    /** @var \SelectQuery $select */
    $select = $this->database->select($table, $alias, $options);
    return $select;
  }

  /**
   * Executes a query.
   *
   * @see db_query()
   *
   * @param string $query
   *   The prepared statement query to run.
   * @param array $args
   *   (optional) An array of values to substitute into the query.
   * @param array $options
   *   (optional) An array of options to control how the query operates.
   *
   * @return \DatabaseStatementInterface
   *   A prepared statement object, already executed.
   */
  protected function getQuery($query, $args = [], $options = []) {
    /** @var \DatabaseStatementInterface $statement */
    $statement = $this->database->query($query, $args, $options);
    return $statement;
  }

}
